@@ -3,8 +3,9 @@ Main interface for iotthingsgraph service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.iotthingsgraph import (
+    from mypy_boto3_iotthingsgraph import (
         Client,
         GetFlowTemplateRevisionsPaginator,
         GetSystemTemplateRevisionsPaginator,
@@ -17,7 +18,7 @@ Usage::
         SearchSystemInstancesPaginator,
         SearchSystemTemplatesPaginator,
         SearchThingsPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -34,8 +35,9 @@ Usage::
     search_system_instances_paginator: SearchSystemInstancesPaginator = client.get_paginator("search_system_instances")
     search_system_templates_paginator: SearchSystemTemplatesPaginator = client.get_paginator("search_system_templates")
     search_things_paginator: SearchThingsPaginator = client.get_paginator("search_things")
+    ```
 """
-from mypy_boto3_iotthingsgraph.client import IoTThingsGraphClient, IoTThingsGraphClient as Client
+from mypy_boto3_iotthingsgraph.client import IoTThingsGraphClient
 from mypy_boto3_iotthingsgraph.paginator import (
     GetFlowTemplateRevisionsPaginator,
     GetSystemTemplateRevisionsPaginator,
@@ -49,6 +51,8 @@ from mypy_boto3_iotthingsgraph.paginator import (
     SearchThingsPaginator,
 )
 
+Client = IoTThingsGraphClient
+
 
 __all__ = (
     "Client",
