@@ -1,10 +1,14 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for iotthingsgraph service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.iotthingsgraph import (
+
+    from mypy_boto3_iotthingsgraph import IoTThingsGraphClient
+    from mypy_boto3_iotthingsgraph.paginator import (
         GetFlowTemplateRevisionsPaginator,
         GetSystemTemplateRevisionsPaginator,
         ListFlowExecutionMessagesPaginator,
@@ -29,12 +33,14 @@ Usage::
     search_system_instances_paginator: SearchSystemInstancesPaginator = client.get_paginator("search_system_instances")
     search_system_templates_paginator: SearchSystemTemplatesPaginator = client.get_paginator("search_system_templates")
     search_things_paginator: SearchThingsPaginator = client.get_paginator("search_things")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from datetime import datetime
 import sys
-from typing import Generator, List, TYPE_CHECKING
+from datetime import datetime
+from typing import Iterator, List
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_iotthingsgraph.type_defs import (
     EntityFilterTypeDef,
     FlowTemplateFilterTypeDef,
@@ -75,59 +81,59 @@ __all__ = (
 
 class GetFlowTemplateRevisionsPaginator(Boto3Paginator):
     """
-    [Paginator.GetFlowTemplateRevisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.5/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.GetFlowTemplateRevisions)
+    [Paginator.GetFlowTemplateRevisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.14/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.GetFlowTemplateRevisions)
     """
 
     def paginate(
         self, id: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[GetFlowTemplateRevisionsResponseTypeDef, None, None]:
+    ) -> Iterator[GetFlowTemplateRevisionsResponseTypeDef]:
         """
-        [GetFlowTemplateRevisions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.5/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.GetFlowTemplateRevisions.paginate)
+        [GetFlowTemplateRevisions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.14/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.GetFlowTemplateRevisions.paginate)
         """
 
 
 class GetSystemTemplateRevisionsPaginator(Boto3Paginator):
     """
-    [Paginator.GetSystemTemplateRevisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.5/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.GetSystemTemplateRevisions)
+    [Paginator.GetSystemTemplateRevisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.14/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.GetSystemTemplateRevisions)
     """
 
     def paginate(
         self, id: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[GetSystemTemplateRevisionsResponseTypeDef, None, None]:
+    ) -> Iterator[GetSystemTemplateRevisionsResponseTypeDef]:
         """
-        [GetSystemTemplateRevisions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.5/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.GetSystemTemplateRevisions.paginate)
+        [GetSystemTemplateRevisions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.14/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.GetSystemTemplateRevisions.paginate)
         """
 
 
 class ListFlowExecutionMessagesPaginator(Boto3Paginator):
     """
-    [Paginator.ListFlowExecutionMessages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.5/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.ListFlowExecutionMessages)
+    [Paginator.ListFlowExecutionMessages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.14/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.ListFlowExecutionMessages)
     """
 
     def paginate(
         self, flowExecutionId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListFlowExecutionMessagesResponseTypeDef, None, None]:
+    ) -> Iterator[ListFlowExecutionMessagesResponseTypeDef]:
         """
-        [ListFlowExecutionMessages.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.5/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.ListFlowExecutionMessages.paginate)
+        [ListFlowExecutionMessages.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.14/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.ListFlowExecutionMessages.paginate)
         """
 
 
 class ListTagsForResourcePaginator(Boto3Paginator):
     """
-    [Paginator.ListTagsForResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.5/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.ListTagsForResource)
+    [Paginator.ListTagsForResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.14/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.ListTagsForResource)
     """
 
     def paginate(
         self, resourceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListTagsForResourceResponseTypeDef, None, None]:
+    ) -> Iterator[ListTagsForResourceResponseTypeDef]:
         """
-        [ListTagsForResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.5/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.ListTagsForResource.paginate)
+        [ListTagsForResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.14/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.ListTagsForResource.paginate)
         """
 
 
 class SearchEntitiesPaginator(Boto3Paginator):
     """
-    [Paginator.SearchEntities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.5/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchEntities)
+    [Paginator.SearchEntities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.14/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchEntities)
     """
 
     def paginate(
@@ -149,15 +155,15 @@ class SearchEntitiesPaginator(Boto3Paginator):
         filters: List[EntityFilterTypeDef] = None,
         namespaceVersion: int = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[SearchEntitiesResponseTypeDef, None, None]:
+    ) -> Iterator[SearchEntitiesResponseTypeDef]:
         """
-        [SearchEntities.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.5/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchEntities.paginate)
+        [SearchEntities.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.14/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchEntities.paginate)
         """
 
 
 class SearchFlowExecutionsPaginator(Boto3Paginator):
     """
-    [Paginator.SearchFlowExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.5/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchFlowExecutions)
+    [Paginator.SearchFlowExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.14/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchFlowExecutions)
     """
 
     def paginate(
@@ -167,60 +173,60 @@ class SearchFlowExecutionsPaginator(Boto3Paginator):
         startTime: datetime = None,
         endTime: datetime = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[SearchFlowExecutionsResponseTypeDef, None, None]:
+    ) -> Iterator[SearchFlowExecutionsResponseTypeDef]:
         """
-        [SearchFlowExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.5/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchFlowExecutions.paginate)
+        [SearchFlowExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.14/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchFlowExecutions.paginate)
         """
 
 
 class SearchFlowTemplatesPaginator(Boto3Paginator):
     """
-    [Paginator.SearchFlowTemplates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.5/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchFlowTemplates)
+    [Paginator.SearchFlowTemplates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.14/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchFlowTemplates)
     """
 
     def paginate(
         self,
         filters: List[FlowTemplateFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[SearchFlowTemplatesResponseTypeDef, None, None]:
+    ) -> Iterator[SearchFlowTemplatesResponseTypeDef]:
         """
-        [SearchFlowTemplates.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.5/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchFlowTemplates.paginate)
+        [SearchFlowTemplates.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.14/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchFlowTemplates.paginate)
         """
 
 
 class SearchSystemInstancesPaginator(Boto3Paginator):
     """
-    [Paginator.SearchSystemInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.5/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchSystemInstances)
+    [Paginator.SearchSystemInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.14/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchSystemInstances)
     """
 
     def paginate(
         self,
         filters: List[SystemInstanceFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[SearchSystemInstancesResponseTypeDef, None, None]:
+    ) -> Iterator[SearchSystemInstancesResponseTypeDef]:
         """
-        [SearchSystemInstances.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.5/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchSystemInstances.paginate)
+        [SearchSystemInstances.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.14/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchSystemInstances.paginate)
         """
 
 
 class SearchSystemTemplatesPaginator(Boto3Paginator):
     """
-    [Paginator.SearchSystemTemplates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.5/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchSystemTemplates)
+    [Paginator.SearchSystemTemplates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.14/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchSystemTemplates)
     """
 
     def paginate(
         self,
         filters: List[SystemTemplateFilterTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[SearchSystemTemplatesResponseTypeDef, None, None]:
+    ) -> Iterator[SearchSystemTemplatesResponseTypeDef]:
         """
-        [SearchSystemTemplates.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.5/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchSystemTemplates.paginate)
+        [SearchSystemTemplates.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.14/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchSystemTemplates.paginate)
         """
 
 
 class SearchThingsPaginator(Boto3Paginator):
     """
-    [Paginator.SearchThings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.5/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchThings)
+    [Paginator.SearchThings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.14/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchThings)
     """
 
     def paginate(
@@ -228,7 +234,7 @@ class SearchThingsPaginator(Boto3Paginator):
         entityId: str,
         namespaceVersion: int = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[SearchThingsResponseTypeDef, None, None]:
+    ) -> Iterator[SearchThingsResponseTypeDef]:
         """
-        [SearchThings.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.5/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchThings.paginate)
+        [SearchThings.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.14/reference/services/iotthingsgraph.html#IoTThingsGraph.Paginator.SearchThings.paginate)
         """
